@@ -60,6 +60,7 @@ tlds = ['xn\\-\\-vermgensberatung\\-pwb',
  'weatherchannel',
  'xn\\-\\-3e0b707e',
  'xn\\-\\-45br5cyl',
+ 'xn\\-\\-4dbrk0ce',
  'xn\\-\\-80adxhks',
  'xn\\-\\-80asehdb',
  'xn\\-\\-8y0a063a',
@@ -682,6 +683,7 @@ tlds = ['xn\\-\\-vermgensberatung\\-pwb',
  'autos',
  'azure',
  'baidu',
+ 'bazar',
  'beats',
  'bible',
  'bingo',
@@ -879,6 +881,7 @@ tlds = ['xn\\-\\-vermgensberatung\\-pwb',
  'citi',
  'city',
  'club',
+ 'coin',
  'cool',
  'coop',
  'cyou',
