@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import itertools
+import functools
 
 from .. import arg, Unit
 from ...lib.argformats import numseq
@@ -16,19 +17,19 @@ class put(Unit):
     def __init__(
         self,
         name : arg(help='The name of the variable to be used.', type=str),
-        value: arg(help='The value for the variable.', type=numseq)
+        value: arg(help='The value for the variable.', type=functools.partial(numseq, typecheck=False))
     ):
         super().__init__(name=check_variable_name(name), value=value)
 
     def process(self, data):
         value = self.args.value
-        if not isinstance(value, int) and not isbuffer(value):
+        if not isinstance(value, (int, float)) and not isbuffer(value):
             try:
                 len(value)
             except TypeError:
                 if isinstance(value, itertools.repeat):
                     value = next(value)
-                if not isinstance(value, int):
+                if not isinstance(value, (int, float)):
                     raise NotImplementedError(F'put does not support {value.__class__.__name__} values.')
             else:
                 if not isinstance(value, list):
