@@ -1,15 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from ...lib.argformats import utf8
-from . import arg, RegexUnit, TransformSubstitutionFactory
+from ...lib.meta import metavars
+from . import arg, RegexUnit
 
 
 class resub(RegexUnit):
     """
-    A unit for performing substitutions based on a binary regular expression
-    pattern. Besides the usual syntax `$k` to insert the `k`-th match group,
-    the unit supports processing the contents of match groups with arbitrary
-    refinery units (see `refinery.units.pattern.TransformSubstitutionFactory`).
+    A unit for performing substitutions based on a binary regular expression pattern. Besides the
+    syntax `{k}` to insert the `k`-th match group, the unit supports processing the contents of
+    match groups with arbitrary refinery units. To do so, use the following F-string-like syntax:
+
+        {match-group:pipeline}
+
+    where `:pipeline` is an optional pipeline of refinery commands as it would be specified on
+    the command line. The value of the corresponding match is post-processed with this command.
     """
     def __init__(self, regex,
         subst: arg('subst', type=utf8, help=(
@@ -23,13 +28,12 @@ class resub(RegexUnit):
         super().__init__(regex=regex, subst=subst, multiline=multiline, ignorecase=ignorecase, count=count)
 
     def process(self, data):
+        def repl(match):
+            return meta.format_bin(spec, self.codec, *match.groups(), **match.groupdict())
         self.log_info('pattern:', self.regex)
         self.log_info('replace:', self.args.subst)
-        try:
-            meta = data.meta
-        except AttributeError:
-            meta = {}
-        repl = TransformSubstitutionFactory(self.args.subst, meta)
+        meta = metavars(data)
+        spec = self.args.subst.decode(self.codec)
         sub = self.regex.sub
         if self.args.count:
             from functools import partial
